# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.shared_step_response import SharedStepResponse

class TestSharedStepResponse(unittest.TestCase):
    """SharedStepResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SharedStepResponse:
        """Test SharedStepResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SharedStepResponse`
        """
        model = SharedStepResponse()
        if include_optional:
            return SharedStepResponse(
                status = True,
                result = qaseio.models.shared_step.SharedStep(
                    hash = '', 
                    title = '', 
                    action = '', 
                    expected_result = '', 
                    steps = [
                        qaseio.models.shared_step_content.SharedStepContent(
                            data = '', 
                            hash = '', 
                            action = '', 
                            expected_result = '', 
                            attachments = [
                                qaseio.models.attachment_hash.AttachmentHash(
                                    size = 56, 
                                    mime = '', 
                                    filename = '', 
                                    url = '', 
                                    hash = '', )
                                ], )
                        ], 
                    data = '', 
                    cases = [
                        56
                        ], 
                    cases_count = 56, 
                    created = '2021-12-30 19:23:59', 
                    updated = '2021-12-30 19:23:59', 
                    created_at = '2021-12-30T19:23:59Z', 
                    updated_at = '2021-12-30T19:23:59Z', )
            )
        else:
            return SharedStepResponse(
        )
        """

    def testSharedStepResponse(self):
        """Test SharedStepResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.test_case import TestCase

class TestTestCase(unittest.TestCase):
    """TestCase unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestCase:
        """Test TestCase
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestCase`
        """
        model = TestCase()
        if include_optional:
            return TestCase(
                id = 56,
                position = 56,
                title = '',
                description = '',
                preconditions = '',
                postconditions = '',
                severity = 56,
                priority = 56,
                type = 56,
                layer = 56,
                is_flaky = 56,
                behavior = 56,
                automation = 56,
                status = 56,
                milestone_id = 56,
                suite_id = 56,
                custom_fields = [
                    qaseio.models.custom_field_value.CustomFieldValue(
                        id = 56, 
                        value = '', )
                    ],
                attachments = [
                    qaseio.models.attachment.Attachment(
                        size = 56, 
                        mime = '', 
                        filename = '', 
                        url = '', )
                    ],
                steps_type = '',
                steps = [
                    qaseio.models.test_step.TestStep(
                        hash = '', 
                        shared_step_hash = '', 
                        shared_step_nested_hash = '', 
                        position = 56, 
                        action = '', 
                        expected_result = '', 
                        data = '', 
                        attachments = [
                            qaseio.models.attachment.Attachment(
                                size = 56, 
                                mime = '', 
                                filename = '', 
                                url = '', )
                            ], 
                        steps = [
                            None
                            ], )
                    ],
                params = None,
                tags = [
                    qaseio.models.tag_value.TagValue(
                        title = '', 
                        internal_id = 56, )
                    ],
                member_id = 56,
                author_id = 56,
                created_at = '2021-12-30T19:23:59Z',
                updated_at = '2021-12-30T19:23:59Z',
                deleted = '2021-12-30T19:23:59.000000Z',
                created = '2021-12-30T19:23:59.000000Z',
                updated = '2021-12-30T19:23:59.000000Z',
                external_issues = [
                    qaseio.models.external_issue.ExternalIssue(
                        type = '', 
                        issues = [
                            qaseio.models.external_issue_issues_inner.ExternalIssue_issues_inner(
                                id = '', 
                                link = '', )
                            ], )
                    ]
            )
        else:
            return TestCase(
        )
        """

    def testTestCase(self):
        """Test TestCase"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from qaseio.models.attachment import Attachment
from qaseio.models.attachment_get import AttachmentGet
from qaseio.models.attachment_hash import AttachmentHash
from qaseio.models.attachment_list_response import AttachmentListResponse
from qaseio.models.attachment_list_response_all_of_result import AttachmentListResponseAllOfResult
from qaseio.models.attachment_response import AttachmentResponse
from qaseio.models.attachment_uploads_response import AttachmentUploadsResponse
from qaseio.models.author import Author
from qaseio.models.author_list_response import AuthorListResponse
from qaseio.models.author_list_response_all_of_result import AuthorListResponseAllOfResult
from qaseio.models.author_response import AuthorResponse
from qaseio.models.base_error_field_response import BaseErrorFieldResponse
from qaseio.models.base_error_field_response_error_fields_inner import BaseErrorFieldResponseErrorFieldsInner
from qaseio.models.base_error_response import BaseErrorResponse
from qaseio.models.base_response import BaseResponse
from qaseio.models.bulk200_response import Bulk200Response
from qaseio.models.bulk200_response_all_of_result import Bulk200ResponseAllOfResult
from qaseio.models.create_results_request_v2 import CreateResultsRequestV2
from qaseio.models.create_results_v2422_response import CreateResultsV2422Response
from qaseio.models.custom_field import CustomField
from qaseio.models.custom_field_create import CustomFieldCreate
from qaseio.models.custom_field_create_value_inner import CustomFieldCreateValueInner
from qaseio.models.custom_field_list_response import CustomFieldListResponse
from qaseio.models.custom_field_response import CustomFieldResponse
from qaseio.models.custom_field_update import CustomFieldUpdate
from qaseio.models.custom_field_value import CustomFieldValue
from qaseio.models.custom_fields_response import CustomFieldsResponse
from qaseio.models.custom_fields_response_all_of_result import CustomFieldsResponseAllOfResult
from qaseio.models.defect import Defect
from qaseio.models.defect_create import DefectCreate
from qaseio.models.defect_list_response import DefectListResponse
from qaseio.models.defect_list_response_all_of_result import DefectListResponseAllOfResult
from qaseio.models.defect_query import DefectQuery
from qaseio.models.defect_response import DefectResponse
from qaseio.models.defect_status import DefectStatus
from qaseio.models.defect_update import DefectUpdate
from qaseio.models.environment import Environment
from qaseio.models.environment_create import EnvironmentCreate
from qaseio.models.environment_list_response import EnvironmentListResponse
from qaseio.models.environment_list_response_all_of_result import EnvironmentListResponseAllOfResult
from qaseio.models.environment_response import EnvironmentResponse
from qaseio.models.environment_update import EnvironmentUpdate
from qaseio.models.external_issue import ExternalIssue
from qaseio.models.external_issue_issues_inner import ExternalIssueIssuesInner
from qaseio.models.hash_response import HashResponse
from qaseio.models.hash_response_all_of_result import HashResponseAllOfResult
from qaseio.models.id_response import IdResponse
from qaseio.models.id_response_all_of_result import IdResponseAllOfResult
from qaseio.models.milestone import Milestone
from qaseio.models.milestone_create import MilestoneCreate
from qaseio.models.milestone_list_response import MilestoneListResponse
from qaseio.models.milestone_list_response_all_of_result import MilestoneListResponseAllOfResult
from qaseio.models.milestone_response import MilestoneResponse
from qaseio.models.milestone_update import MilestoneUpdate
from qaseio.models.plan import Plan
from qaseio.models.plan_create import PlanCreate
from qaseio.models.plan_detailed import PlanDetailed
from qaseio.models.plan_detailed_all_of_cases import PlanDetailedAllOfCases
from qaseio.models.plan_list_response import PlanListResponse
from qaseio.models.plan_list_response_all_of_result import PlanListResponseAllOfResult
from qaseio.models.plan_query import PlanQuery
from qaseio.models.plan_response import PlanResponse
from qaseio.models.plan_update import PlanUpdate
from qaseio.models.project import Project
from qaseio.models.project_access import ProjectAccess
from qaseio.models.project_code_response import ProjectCodeResponse
from qaseio.models.project_code_response_all_of_result import ProjectCodeResponseAllOfResult
from qaseio.models.project_counts import ProjectCounts
from qaseio.models.project_counts_defects import ProjectCountsDefects
from qaseio.models.project_counts_runs import ProjectCountsRuns
from qaseio.models.project_create import ProjectCreate
from qaseio.models.project_list_response import ProjectListResponse
from qaseio.models.project_list_response_all_of_result import ProjectListResponseAllOfResult
from qaseio.models.project_response import ProjectResponse
from qaseio.models.qql_defect import QqlDefect
from qaseio.models.qql_plan import QqlPlan
from qaseio.models.qql_test_case import QqlTestCase
from qaseio.models.relation_suite import RelationSuite
from qaseio.models.relation_suite_item import RelationSuiteItem
from qaseio.models.requirement import Requirement
from qaseio.models.response import Response
from qaseio.models.result import Result
from qaseio.models.result_attachment import ResultAttachment
from qaseio.models.result_create import ResultCreate
from qaseio.models.result_create_bulk import ResultCreateBulk
from qaseio.models.result_create_case import ResultCreateCase
from qaseio.models.result_create_response import ResultCreateResponse
from qaseio.models.result_create_response_all_of_result import ResultCreateResponseAllOfResult
from qaseio.models.result_create_v2 import ResultCreateV2
from qaseio.models.result_execution import ResultExecution
from qaseio.models.result_list_response import ResultListResponse
from qaseio.models.result_list_response_all_of_result import ResultListResponseAllOfResult
from qaseio.models.result_relations import ResultRelations
from qaseio.models.result_response import ResultResponse
from qaseio.models.result_step import ResultStep
from qaseio.models.result_step_data import ResultStepData
from qaseio.models.result_step_execution import ResultStepExecution
from qaseio.models.result_update import ResultUpdate
from qaseio.models.resultcreate_bulk import ResultcreateBulk
from qaseio.models.run import Run
from qaseio.models.run_create import RunCreate
from qaseio.models.run_environment import RunEnvironment
from qaseio.models.run_list_response import RunListResponse
from qaseio.models.run_list_response_all_of_result import RunListResponseAllOfResult
from qaseio.models.run_milestone import RunMilestone
from qaseio.models.run_public import RunPublic
from qaseio.models.run_public_response import RunPublicResponse
from qaseio.models.run_public_response_all_of_result import RunPublicResponseAllOfResult
from qaseio.models.run_response import RunResponse
from qaseio.models.run_stats import RunStats
from qaseio.models.search_response import SearchResponse
from qaseio.models.search_response_all_of_result import SearchResponseAllOfResult
from qaseio.models.search_response_all_of_result_entities import SearchResponseAllOfResultEntities
from qaseio.models.shared_step import SharedStep
from qaseio.models.shared_step_content import SharedStepContent
from qaseio.models.shared_step_content_create import SharedStepContentCreate
from qaseio.models.shared_step_create import SharedStepCreate
from qaseio.models.shared_step_list_response import SharedStepListResponse
from qaseio.models.shared_step_list_response_all_of_result import SharedStepListResponseAllOfResult
from qaseio.models.shared_step_response import SharedStepResponse
from qaseio.models.shared_step_update import SharedStepUpdate
from qaseio.models.suite import Suite
from qaseio.models.suite_create import SuiteCreate
from qaseio.models.suite_delete import SuiteDelete
from qaseio.models.suite_list_response import SuiteListResponse
from qaseio.models.suite_list_response_all_of_result import SuiteListResponseAllOfResult
from qaseio.models.suite_response import SuiteResponse
from qaseio.models.suite_update import SuiteUpdate
from qaseio.models.system_field import SystemField
from qaseio.models.system_field_list_response import SystemFieldListResponse
from qaseio.models.system_field_option import SystemFieldOption
from qaseio.models.tag_value import TagValue
from qaseio.models.test_case import TestCase
from qaseio.models.test_case_create import TestCaseCreate
from qaseio.models.test_case_external_issues import TestCaseExternalIssues
from qaseio.models.test_case_external_issues_links_inner import TestCaseExternalIssuesLinksInner
from qaseio.models.test_case_list_response import TestCaseListResponse
from qaseio.models.test_case_list_response_all_of_result import TestCaseListResponseAllOfResult
from qaseio.models.test_case_params import TestCaseParams
from qaseio.models.test_case_query import TestCaseQuery
from qaseio.models.test_case_response import TestCaseResponse
from qaseio.models.test_case_update import TestCaseUpdate
from qaseio.models.test_casebulk import TestCasebulk
from qaseio.models.test_casebulk_cases_inner import TestCasebulkCasesInner
from qaseio.models.test_caseexternal_issues import TestCaseexternalIssues
from qaseio.models.test_step import TestStep
from qaseio.models.test_step_create import TestStepCreate
from qaseio.models.test_step_result import TestStepResult
from qaseio.models.test_step_result_create import TestStepResultCreate



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.project_list_response import ProjectListResponse

class TestProjectListResponse(unittest.TestCase):
    """ProjectListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ProjectListResponse:
        """Test ProjectListResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ProjectListResponse`
        """
        model = ProjectListResponse()
        if include_optional:
            return ProjectListResponse(
                status = True,
                result = qaseio.models.project_list_response_all_of_result.ProjectListResponse_allOf_result(
                    total = 56, 
                    filtered = 56, 
                    count = 56, 
                    entities = [
                        qaseio.models.project.Project(
                            title = '', 
                            code = '', 
                            counts = qaseio.models.project_counts.Project_counts(
                                cases = 56, 
                                suites = 56, 
                                milestones = 56, 
                                runs = qaseio.models.project_counts_runs.Project_counts_runs(
                                    total = 56, 
                                    active = 56, ), 
                                defects = qaseio.models.project_counts_defects.Project_counts_defects(
                                    total = 56, 
                                    open = 56, ), ), )
                        ], )
            )
        else:
            return ProjectListResponse(
        )
        """

    def testProjectListResponse(self):
        """Test ProjectListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictInt, StrictStr
from pydantic import Field
from typing_extensions import Annotated
from qaseio.models.test_step_create import TestStepCreate
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class TestCaseUpdate(BaseModel):
    """
    TestCaseUpdate
    """ # noqa: E501
    description: Optional[StrictStr] = None
    preconditions: Optional[StrictStr] = None
    postconditions: Optional[StrictStr] = None
    title: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    severity: Optional[StrictInt] = None
    priority: Optional[StrictInt] = None
    behavior: Optional[StrictInt] = None
    type: Optional[StrictInt] = None
    layer: Optional[StrictInt] = None
    is_flaky: Optional[StrictInt] = None
    suite_id: Optional[StrictInt] = None
    milestone_id: Optional[StrictInt] = None
    automation: Optional[StrictInt] = None
    status: Optional[StrictInt] = None
    attachments: Optional[List[StrictStr]] = Field(default=None, description="A list of Attachment hashes.")
    steps: Optional[List[TestStepCreate]] = None
    tags: Optional[List[StrictStr]] = None
    params: Optional[Dict[str, List[StrictStr]]] = None
    custom_field: Optional[Dict[str, StrictStr]] = Field(default=None, description="A map of custom fields values (id => value)")
    __properties: ClassVar[List[str]] = ["description", "preconditions", "postconditions", "title", "severity", "priority", "behavior", "type", "layer", "is_flaky", "suite_id", "milestone_id", "automation", "status", "attachments", "steps", "tags", "params", "custom_field"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of TestCaseUpdate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in steps (list)
        _items = []
        if self.steps:
            for _item in self.steps:
                if _item:
                    _items.append(_item.to_dict())
            _dict['steps'] = _items
        # set to None if params (nullable) is None
        # and model_fields_set contains the field
        if self.params is None and "params" in self.model_fields_set:
            _dict['params'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of TestCaseUpdate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "description": obj.get("description"),
            "preconditions": obj.get("preconditions"),
            "postconditions": obj.get("postconditions"),
            "title": obj.get("title"),
            "severity": obj.get("severity"),
            "priority": obj.get("priority"),
            "behavior": obj.get("behavior"),
            "type": obj.get("type"),
            "layer": obj.get("layer"),
            "is_flaky": obj.get("is_flaky"),
            "suite_id": obj.get("suite_id"),
            "milestone_id": obj.get("milestone_id"),
            "automation": obj.get("automation"),
            "status": obj.get("status"),
            "attachments": obj.get("attachments"),
            "steps": [TestStepCreate.from_dict(_item) for _item in obj.get("steps")] if obj.get("steps") is not None else None,
            "tags": obj.get("tags"),
            "params": obj.get("params"),
            "custom_field": obj.get("custom_field")
        })
        return _obj





# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.defect_list_response import DefectListResponse

class TestDefectListResponse(unittest.TestCase):
    """DefectListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DefectListResponse:
        """Test DefectListResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DefectListResponse`
        """
        model = DefectListResponse()
        if include_optional:
            return DefectListResponse(
                status = True,
                result = qaseio.models.defect_list_response_all_of_result.DefectListResponse_allOf_result(
                    total = 56, 
                    filtered = 56, 
                    count = 56, 
                    entities = [
                        qaseio.models.defect.Defect(
                            id = 56, 
                            title = '', 
                            actual_result = '', 
                            severity = '', 
                            status = '', 
                            milestone_id = 56, 
                            custom_fields = [
                                qaseio.models.custom_field_value.CustomFieldValue(
                                    id = 56, 
                                    value = '', )
                                ], 
                            attachments = [
                                qaseio.models.attachment.Attachment(
                                    size = 56, 
                                    mime = '', 
                                    filename = '', 
                                    url = '', )
                                ], 
                            resolved_at = '2021-12-30T19:23:59Z', 
                            member_id = 56, 
                            author_id = 56, 
                            external_data = '', 
                            tags = [
                                qaseio.models.tag_value.TagValue(
                                    title = '', 
                                    internal_id = 56, )
                                ], 
                            created_at = '2021-12-30T19:23:59Z', 
                            updated_at = '2021-12-30T19:23:59Z', 
                            created = '2021-12-30 19:23:59', 
                            updated = '2021-12-30 19:23:59', )
                        ], )
            )
        else:
            return DefectListResponse(
        )
        """

    def testDefectListResponse(self):
        """Test DefectListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import io
import warnings

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Dict, List, Optional, Tuple, Union, Any

try:
    from typing import Annotated
except ImportError:
    from typing_extensions import Annotated

from pydantic import Field
from typing_extensions import Annotated
from pydantic import StrictInt, StrictStr, field_validator

from typing import Optional

from qaseio.models.base_response import BaseResponse
from qaseio.models.custom_field_create import CustomFieldCreate
from qaseio.models.custom_field_list_response import CustomFieldListResponse
from qaseio.models.custom_field_response import CustomFieldResponse
from qaseio.models.custom_field_update import CustomFieldUpdate
from qaseio.models.id_response import IdResponse

from qaseio.api_client import ApiClient
from qaseio.api_response import ApiResponse
from qaseio.rest import RESTResponseType


class CustomFieldsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_custom_field(
        self,
        custom_field_create: CustomFieldCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> IdResponse:
        """Create new Custom Field.

        This method allows to create custom field. 

        :param custom_field_create: (required)
        :type custom_field_create: CustomFieldCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_custom_field_serialize(
            custom_field_create=custom_field_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IdResponse",
            '400': None,
            '401': None,
            '403': None,
            '422': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_custom_field_with_http_info(
        self,
        custom_field_create: CustomFieldCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[IdResponse]:
        """Create new Custom Field.

        This method allows to create custom field. 

        :param custom_field_create: (required)
        :type custom_field_create: CustomFieldCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_custom_field_serialize(
            custom_field_create=custom_field_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IdResponse",
            '400': None,
            '401': None,
            '403': None,
            '422': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_custom_field_without_preload_content(
        self,
        custom_field_create: CustomFieldCreate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Create new Custom Field.

        This method allows to create custom field. 

        :param custom_field_create: (required)
        :type custom_field_create: CustomFieldCreate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_custom_field_serialize(
            custom_field_create=custom_field_create,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "IdResponse",
            '400': None,
            '401': None,
            '403': None,
            '422': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_custom_field_serialize(
        self,
        custom_field_create,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if custom_field_create is not None:
            _body_params = custom_field_create


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/custom_field',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def delete_custom_field(
        self,
        id: Annotated[StrictInt, Field(description="Identifier.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BaseResponse:
        """Delete Custom Field by id.

        This method allows to delete custom field. 

        :param id: Identifier. (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_custom_field_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BaseResponse",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def delete_custom_field_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="Identifier.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BaseResponse]:
        """Delete Custom Field by id.

        This method allows to delete custom field. 

        :param id: Identifier. (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_custom_field_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BaseResponse",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def delete_custom_field_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="Identifier.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Delete Custom Field by id.

        This method allows to delete custom field. 

        :param id: Identifier. (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._delete_custom_field_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BaseResponse",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _delete_custom_field_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth'
        ]

        return self.api_client.param_serialize(
            method='DELETE',
            resource_path='/custom_field/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_custom_field(
        self,
        id: Annotated[StrictInt, Field(description="Identifier.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CustomFieldResponse:
        """Get Custom Field by id.

        This method allows to retrieve custom field. 

        :param id: Identifier. (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_custom_field_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomFieldResponse",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_custom_field_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="Identifier.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CustomFieldResponse]:
        """Get Custom Field by id.

        This method allows to retrieve custom field. 

        :param id: Identifier. (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_custom_field_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomFieldResponse",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_custom_field_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="Identifier.")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Custom Field by id.

        This method allows to retrieve custom field. 

        :param id: Identifier. (required)
        :type id: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_custom_field_serialize(
            id=id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomFieldResponse",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_custom_field_serialize(
        self,
        id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/custom_field/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_custom_fields(
        self,
        entity: Optional[StrictStr] = None,
        type: Optional[StrictStr] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="A number of entities in result set.")] = None,
        offset: Annotated[Optional[Annotated[int, Field(le=100000, strict=True, ge=0)]], Field(description="How many entities should be skipped.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> CustomFieldListResponse:
        """Get all Custom Fields.

        This method allows to retrieve and filter custom fields. 

        :param entity:
        :type entity: str
        :param type:
        :type type: str
        :param limit: A number of entities in result set.
        :type limit: int
        :param offset: How many entities should be skipped.
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_custom_fields_serialize(
            entity=entity,
            type=type,
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomFieldListResponse",
            '400': None,
            '401': None,
            '403': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_custom_fields_with_http_info(
        self,
        entity: Optional[StrictStr] = None,
        type: Optional[StrictStr] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="A number of entities in result set.")] = None,
        offset: Annotated[Optional[Annotated[int, Field(le=100000, strict=True, ge=0)]], Field(description="How many entities should be skipped.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[CustomFieldListResponse]:
        """Get all Custom Fields.

        This method allows to retrieve and filter custom fields. 

        :param entity:
        :type entity: str
        :param type:
        :type type: str
        :param limit: A number of entities in result set.
        :type limit: int
        :param offset: How many entities should be skipped.
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_custom_fields_serialize(
            entity=entity,
            type=type,
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomFieldListResponse",
            '400': None,
            '401': None,
            '403': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_custom_fields_without_preload_content(
        self,
        entity: Optional[StrictStr] = None,
        type: Optional[StrictStr] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=100, strict=True, ge=1)]], Field(description="A number of entities in result set.")] = None,
        offset: Annotated[Optional[Annotated[int, Field(le=100000, strict=True, ge=0)]], Field(description="How many entities should be skipped.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get all Custom Fields.

        This method allows to retrieve and filter custom fields. 

        :param entity:
        :type entity: str
        :param type:
        :type type: str
        :param limit: A number of entities in result set.
        :type limit: int
        :param offset: How many entities should be skipped.
        :type offset: int
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_custom_fields_serialize(
            entity=entity,
            type=type,
            limit=limit,
            offset=offset,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "CustomFieldListResponse",
            '400': None,
            '401': None,
            '403': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_custom_fields_serialize(
        self,
        entity,
        type,
        limit,
        offset,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if entity is not None:
            
            _query_params.append(('entity', entity))
            
        if type is not None:
            
            _query_params.append(('type', type))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/custom_field',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def update_custom_field(
        self,
        id: Annotated[StrictInt, Field(description="Identifier.")],
        custom_field_update: CustomFieldUpdate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> BaseResponse:
        """Update Custom Field by id.

        This method allows to update custom field. 

        :param id: Identifier. (required)
        :type id: int
        :param custom_field_update: (required)
        :type custom_field_update: CustomFieldUpdate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_custom_field_serialize(
            id=id,
            custom_field_update=custom_field_update,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BaseResponse",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def update_custom_field_with_http_info(
        self,
        id: Annotated[StrictInt, Field(description="Identifier.")],
        custom_field_update: CustomFieldUpdate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[BaseResponse]:
        """Update Custom Field by id.

        This method allows to update custom field. 

        :param id: Identifier. (required)
        :type id: int
        :param custom_field_update: (required)
        :type custom_field_update: CustomFieldUpdate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_custom_field_serialize(
            id=id,
            custom_field_update=custom_field_update,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BaseResponse",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def update_custom_field_without_preload_content(
        self,
        id: Annotated[StrictInt, Field(description="Identifier.")],
        custom_field_update: CustomFieldUpdate,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Update Custom Field by id.

        This method allows to update custom field. 

        :param id: Identifier. (required)
        :type id: int
        :param custom_field_update: (required)
        :type custom_field_update: CustomFieldUpdate
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._update_custom_field_serialize(
            id=id,
            custom_field_update=custom_field_update,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "BaseResponse",
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': None,
            '429': None,
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _update_custom_field_serialize(
        self,
        id,
        custom_field_update,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params['id'] = id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if custom_field_update is not None:
            _body_params = custom_field_update


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth'
        ]

        return self.api_client.param_serialize(
            method='PATCH',
            resource_path='/custom_field/{id}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.projects_api import ProjectsApi


class TestProjectsApi(unittest.TestCase):
    """ProjectsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ProjectsApi()

    def tearDown(self) -> None:
        pass

    def test_create_project(self) -> None:
        """Test case for create_project

        Create new project.
        """
        pass

    def test_delete_project(self) -> None:
        """Test case for delete_project

        Delete Project by code.
        """
        pass

    def test_get_project(self) -> None:
        """Test case for get_project

        Get Project by code.
        """
        pass

    def test_get_projects(self) -> None:
        """Test case for get_projects

        Get All Projects.
        """
        pass

    def test_grant_access_to_project(self) -> None:
        """Test case for grant_access_to_project

        Grant access to project by code.
        """
        pass

    def test_revoke_access_to_project(self) -> None:
        """Test case for revoke_access_to_project

        Revoke access to project by code.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.shared_step import SharedStep

class TestSharedStep(unittest.TestCase):
    """SharedStep unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SharedStep:
        """Test SharedStep
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SharedStep`
        """
        model = SharedStep()
        if include_optional:
            return SharedStep(
                hash = '',
                title = '',
                action = '',
                expected_result = '',
                steps = [
                    qaseio.models.shared_step_content.SharedStepContent(
                        data = '', 
                        hash = '', 
                        action = '', 
                        expected_result = '', 
                        attachments = [
                            qaseio.models.attachment_hash.AttachmentHash(
                                size = 56, 
                                mime = '', 
                                filename = '', 
                                url = '', 
                                hash = '', )
                            ], )
                    ],
                data = '',
                cases = [
                    56
                    ],
                cases_count = 56,
                created = '2021-12-30 19:23:59',
                updated = '2021-12-30 19:23:59',
                created_at = '2021-12-30T19:23:59Z',
                updated_at = '2021-12-30T19:23:59Z'
            )
        else:
            return SharedStep(
        )
        """

    def testSharedStep(self):
        """Test SharedStep"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.result_update import ResultUpdate

class TestResultUpdate(unittest.TestCase):
    """ResultUpdate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultUpdate:
        """Test ResultUpdate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResultUpdate`
        """
        model = ResultUpdate()
        if include_optional:
            return ResultUpdate(
                status = 'in_progress',
                time_ms = 0,
                defect = True,
                attachments = [
                    ''
                    ],
                stacktrace = '',
                comment = '',
                steps = [
                    qaseio.models.test_step_result_create.TestStepResultCreate(
                        position = 56, 
                        status = 'passed', 
                        comment = '', 
                        attachments = [
                            ''
                            ], 
                        action = '', 
                        expected_result = '', 
                        data = '', 
                        steps = [
                            None
                            ], )
                    ]
            )
        else:
            return ResultUpdate(
        )
        """

    def testResultUpdate(self):
        """Test ResultUpdate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.search_response_all_of_result_entities import SearchResponseAllOfResultEntities

class TestSearchResponseAllOfResultEntities(unittest.TestCase):
    """SearchResponseAllOfResultEntities unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SearchResponseAllOfResultEntities:
        """Test SearchResponseAllOfResultEntities
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SearchResponseAllOfResultEntities`
        """
        model = SearchResponseAllOfResultEntities()
        if include_optional:
            return SearchResponseAllOfResultEntities(
                id = 56,
                title = '',
                description = '',
                status = '',
                status_text = '',
                start_time = '2021-12-30T19:23:59Z',
                end_time = '2021-12-30T19:23:59Z',
                public = True,
                stats = qaseio.models.run_stats.Run_stats(
                    total = 56, 
                    untested = 56, 
                    passed = 56, 
                    failed = 56, 
                    blocked = 56, 
                    skipped = 56, 
                    retest = 56, 
                    in_progress = 56, 
                    invalid = 56, ),
                time_spent = 56,
                environment = qaseio.models.run_environment.Run_environment(
                    title = '', 
                    description = '', 
                    slug = '', 
                    host = '', ),
                milestone = qaseio.models.run_milestone.Run_milestone(
                    title = '', 
                    description = '', ),
                custom_fields = [
                    qaseio.models.custom_field_value.CustomFieldValue(
                        id = 56, 
                        value = '', )
                    ],
                tags = [
                    qaseio.models.tag_value.TagValue(
                        title = '', 
                        internal_id = 56, )
                    ],
                cases = [
                    56
                    ],
                hash = '',
                comment = '',
                stacktrace = '',
                run_id = 56,
                case_id = 56,
                steps = [
                    qaseio.models.test_step.TestStep(
                        hash = '', 
                        shared_step_hash = '', 
                        shared_step_nested_hash = '', 
                        position = 56, 
                        action = '', 
                        expected_result = '', 
                        data = '', 
                        attachments = [
                            qaseio.models.attachment.Attachment(
                                size = 56, 
                                mime = '', 
                                filename = '', 
                                url = '', )
                            ], )
                    ],
                is_api_result = True,
                time_spent_ms = 56,
                attachments = [
                    qaseio.models.attachment.Attachment(
                        size = 56, 
                        mime = '', 
                        filename = '', 
                        url = '', )
                    ],
                parent_id = 56,
                member_id = 56,
                type = 56,
                created_at = '2021-12-30T19:23:59Z',
                updated_at = '2021-12-30T19:23:59Z',
                position = 56,
                preconditions = '',
                postconditions = '',
                severity = '',
                priority = 56,
                layer = 56,
                is_flaky = 56,
                behavior = 56,
                automation = 56,
                milestone_id = 56,
                suite_id = 56,
                steps_type = '',
                params = None,
                author_id = 56,
                actual_result = '',
                resolved = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                external_data = '',
                cases_count = 56
            )
        else:
            return SearchResponseAllOfResultEntities(
        )
        """

    def testSearchResponseAllOfResultEntities(self):
        """Test SearchResponseAllOfResultEntities"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.test_case_list_response import TestCaseListResponse

class TestTestCaseListResponse(unittest.TestCase):
    """TestCaseListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TestCaseListResponse:
        """Test TestCaseListResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TestCaseListResponse`
        """
        model = TestCaseListResponse()
        if include_optional:
            return TestCaseListResponse(
                status = True,
                result = qaseio.models.test_case_list_response_all_of_result.TestCaseListResponse_allOf_result(
                    total = 56, 
                    filtered = 56, 
                    count = 56, 
                    entities = [
                        qaseio.models.test_case.TestCase(
                            id = 56, 
                            position = 56, 
                            title = '', 
                            description = '', 
                            preconditions = '', 
                            postconditions = '', 
                            severity = 56, 
                            priority = 56, 
                            type = 56, 
                            layer = 56, 
                            is_flaky = 56, 
                            behavior = 56, 
                            automation = 56, 
                            status = 56, 
                            milestone_id = 56, 
                            suite_id = 56, 
                            custom_fields = [
                                qaseio.models.custom_field_value.CustomFieldValue(
                                    id = 56, 
                                    value = '', )
                                ], 
                            attachments = [
                                qaseio.models.attachment.Attachment(
                                    size = 56, 
                                    mime = '', 
                                    filename = '', 
                                    url = '', )
                                ], 
                            steps_type = '', 
                            steps = [
                                qaseio.models.test_step.TestStep(
                                    hash = '', 
                                    shared_step_hash = '', 
                                    shared_step_nested_hash = '', 
                                    position = 56, 
                                    action = '', 
                                    expected_result = '', 
                                    data = '', )
                                ], 
                            params = null, 
                            tags = [
                                qaseio.models.tag_value.TagValue(
                                    title = '', 
                                    internal_id = 56, )
                                ], 
                            member_id = 56, 
                            author_id = 56, 
                            created_at = '2021-12-30T19:23:59Z', 
                            updated_at = '2021-12-30T19:23:59Z', 
                            deleted = '2021-12-30T19:23:59.000000Z', 
                            created = '2021-12-30T19:23:59.000000Z', 
                            updated = '2021-12-30T19:23:59.000000Z', 
                            external_issues = [
                                qaseio.models.external_issue.ExternalIssue(
                                    type = '', 
                                    issues = [
                                        qaseio.models.external_issue_issues_inner.ExternalIssue_issues_inner(
                                            id = '', 
                                            link = '', )
                                        ], )
                                ], )
                        ], )
            )
        else:
            return TestCaseListResponse(
        )
        """

    def testTestCaseListResponse(self):
        """Test TestCaseListResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import io
import warnings

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Dict, List, Optional, Tuple, Union, Any

try:
    from typing import Annotated
except ImportError:
    from typing_extensions import Annotated

from pydantic import StrictInt, StrictStr

from qaseio.models.create_results_request_v2 import CreateResultsRequestV2

from qaseio.api_client import ApiClient
from qaseio.api_response import ApiResponse
from qaseio.rest import RESTResponseType


class ResultApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def create_results_v2(
        self,
        project_code: StrictStr,
        run_id: StrictInt,
        create_results_request_v2: CreateResultsRequestV2,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """(Beta) Bulk create test run result.

        This method allows to create a lot of test run result at once.  If there is no free space left in your team account, when attempting to upload an attachment, e.g., through reporters, you will receive an error with code 507 - Insufficient Storage. 

        :param project_code: (required)
        :type project_code: str
        :param run_id: (required)
        :type run_id: int
        :param create_results_request_v2: (required)
        :type create_results_request_v2: CreateResultsRequestV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_results_v2_serialize(
            project_code=project_code,
            run_id=run_id,
            create_results_request_v2=create_results_request_v2,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': "CreateResultsV2422Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def create_results_v2_with_http_info(
        self,
        project_code: StrictStr,
        run_id: StrictInt,
        create_results_request_v2: CreateResultsRequestV2,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """(Beta) Bulk create test run result.

        This method allows to create a lot of test run result at once.  If there is no free space left in your team account, when attempting to upload an attachment, e.g., through reporters, you will receive an error with code 507 - Insufficient Storage. 

        :param project_code: (required)
        :type project_code: str
        :param run_id: (required)
        :type run_id: int
        :param create_results_request_v2: (required)
        :type create_results_request_v2: CreateResultsRequestV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_results_v2_serialize(
            project_code=project_code,
            run_id=run_id,
            create_results_request_v2=create_results_request_v2,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': "CreateResultsV2422Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def create_results_v2_without_preload_content(
        self,
        project_code: StrictStr,
        run_id: StrictInt,
        create_results_request_v2: CreateResultsRequestV2,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """(Beta) Bulk create test run result.

        This method allows to create a lot of test run result at once.  If there is no free space left in your team account, when attempting to upload an attachment, e.g., through reporters, you will receive an error with code 507 - Insufficient Storage. 

        :param project_code: (required)
        :type project_code: str
        :param run_id: (required)
        :type run_id: int
        :param create_results_request_v2: (required)
        :type create_results_request_v2: CreateResultsRequestV2
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._create_results_v2_serialize(
            project_code=project_code,
            run_id=run_id,
            create_results_request_v2=create_results_request_v2,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '202': None,
            '400': None,
            '401': None,
            '403': None,
            '404': None,
            '422': "CreateResultsV2422Response",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _create_results_v2_serialize(
        self,
        project_code,
        run_id,
        create_results_request_v2,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> Tuple:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if project_code is not None:
            _path_params['project_code'] = project_code
        if run_id is not None:
            _path_params['run_id'] = run_id
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if create_results_request_v2 is not None:
            _body_params = create_results_request_v2


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'TokenAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/{project_code}/run/{run_id}/results',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.run import Run

class TestRun(unittest.TestCase):
    """Run unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Run:
        """Test Run
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Run`
        """
        model = Run()
        if include_optional:
            return Run(
                id = 56,
                title = '',
                description = '',
                status = 56,
                status_text = '',
                start_time = '2021-12-30T19:23:59Z',
                end_time = '2021-12-30T19:23:59Z',
                public = True,
                stats = qaseio.models.run_stats.Run_stats(
                    total = 56, 
                    untested = 56, 
                    passed = 56, 
                    failed = 56, 
                    blocked = 56, 
                    skipped = 56, 
                    retest = 56, 
                    in_progress = 56, 
                    invalid = 56, ),
                time_spent = 56,
                environment = qaseio.models.run_environment.Run_environment(
                    title = '', 
                    description = '', 
                    slug = '', 
                    host = '', ),
                milestone = qaseio.models.run_milestone.Run_milestone(
                    title = '', 
                    description = '', ),
                custom_fields = [
                    qaseio.models.custom_field_value.CustomFieldValue(
                        id = 56, 
                        value = '', )
                    ],
                tags = [
                    qaseio.models.tag_value.TagValue(
                        title = '', 
                        internal_id = 56, )
                    ],
                cases = [
                    56
                    ]
            )
        else:
            return Run(
        )
        """

    def testRun(self):
        """Test Run"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.run_response import RunResponse

class TestRunResponse(unittest.TestCase):
    """RunResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RunResponse:
        """Test RunResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RunResponse`
        """
        model = RunResponse()
        if include_optional:
            return RunResponse(
                status = True,
                result = qaseio.models.run.Run(
                    id = 56, 
                    title = '', 
                    description = '', 
                    status = 56, 
                    status_text = '', 
                    start_time = '2021-12-30T19:23:59Z', 
                    end_time = '2021-12-30T19:23:59Z', 
                    public = True, 
                    stats = qaseio.models.run_stats.Run_stats(
                        total = 56, 
                        untested = 56, 
                        passed = 56, 
                        failed = 56, 
                        blocked = 56, 
                        skipped = 56, 
                        retest = 56, 
                        in_progress = 56, 
                        invalid = 56, ), 
                    time_spent = 56, 
                    environment = qaseio.models.run_environment.Run_environment(
                        title = '', 
                        description = '', 
                        slug = '', 
                        host = '', ), 
                    milestone = qaseio.models.run_milestone.Run_milestone(
                        title = '', 
                        description = '', ), 
                    custom_fields = [
                        qaseio.models.custom_field_value.CustomFieldValue(
                            id = 56, 
                            value = '', )
                        ], 
                    tags = [
                        qaseio.models.tag_value.TagValue(
                            title = '', 
                            internal_id = 56, )
                        ], 
                    cases = [
                        56
                        ], )
            )
        else:
            return RunResponse(
        )
        """

    def testRunResponse(self):
        """Test RunResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.attachments_api import AttachmentsApi


class TestAttachmentsApi(unittest.TestCase):
    """AttachmentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AttachmentsApi()

    def tearDown(self) -> None:
        pass

    def test_delete_attachment(self) -> None:
        """Test case for delete_attachment

        Remove attachment by Hash.
        """
        pass

    def test_get_attachment(self) -> None:
        """Test case for get_attachment

        Get attachment by Hash.
        """
        pass

    def test_get_attachments(self) -> None:
        """Test case for get_attachments

        Get all attachments.
        """
        pass

    def test_upload_attachment(self) -> None:
        """Test case for upload_attachment

        Upload attachment.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.resultcreate_bulk import ResultcreateBulk

class TestResultcreateBulk(unittest.TestCase):
    """ResultcreateBulk unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResultcreateBulk:
        """Test ResultcreateBulk
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResultcreateBulk`
        """
        model = ResultcreateBulk()
        if include_optional:
            return ResultcreateBulk(
                results = [
                    qaseio.models.result_create.ResultCreate(
                        case_id = 56, 
                        case = qaseio.models.result_create_case.ResultCreate_case(
                            title = '', 
                            suite_title = '', 
                            description = '', 
                            preconditions = '', 
                            postconditions = '', 
                            layer = '', 
                            severity = '', 
                            priority = '', ), 
                        status = '', 
                        start_time = 0, 
                        time = 0, 
                        time_ms = 0, 
                        defect = True, 
                        attachments = [
                            ''
                            ], 
                        stacktrace = '', 
                        comment = '', 
                        param = {
                            'key' : ''
                            }, 
                        steps = [
                            qaseio.models.test_step_result_create.TestStepResultCreate(
                                position = 56, 
                                status = 'passed', 
                                comment = '', 
                                action = '', 
                                expected_result = '', 
                                data = '', )
                            ], 
                        author_id = 56, )
                    ]
            )
        else:
            return ResultcreateBulk(
                results = [
                    qaseio.models.result_create.ResultCreate(
                        case_id = 56, 
                        case = qaseio.models.result_create_case.ResultCreate_case(
                            title = '', 
                            suite_title = '', 
                            description = '', 
                            preconditions = '', 
                            postconditions = '', 
                            layer = '', 
                            severity = '', 
                            priority = '', ), 
                        status = '', 
                        start_time = 0, 
                        time = 0, 
                        time_ms = 0, 
                        defect = True, 
                        attachments = [
                            ''
                            ], 
                        stacktrace = '', 
                        comment = '', 
                        param = {
                            'key' : ''
                            }, 
                        steps = [
                            qaseio.models.test_step_result_create.TestStepResultCreate(
                                position = 56, 
                                status = 'passed', 
                                comment = '', 
                                action = '', 
                                expected_result = '', 
                                data = '', )
                            ], 
                        author_id = 56, )
                    ],
        )
        """

    def testResultcreateBulk(self):
        """Test ResultcreateBulk"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
from inspect import getfullargspec
import json
import pprint
import re  # noqa: F401

from typing import Any, List, Optional
from pydantic import BaseModel, Field, StrictStr, ValidationError, field_validator
from qaseio.models.defect_query import DefectQuery
from qaseio.models.plan_query import PlanQuery
from qaseio.models.requirement import Requirement
from qaseio.models.result import Result
from qaseio.models.run import Run
from qaseio.models.test_case_query import TestCaseQuery
from typing import Union, Any, List, TYPE_CHECKING, Optional, Dict
from typing_extensions import Literal
from pydantic import StrictStr, Field
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

SEARCHRESPONSEALLOFRESULTENTITIES_ONE_OF_SCHEMAS = ["DefectQuery", "PlanQuery", "Requirement", "Result", "Run", "TestCaseQuery"]

class SearchResponseAllOfResultEntities(BaseModel):
    """
    SearchResponseAllOfResultEntities
    """
    # data type: Run
    oneof_schema_1_validator: Optional[Run] = None
    # data type: Result
    oneof_schema_2_validator: Optional[Result] = None
    # data type: Requirement
    oneof_schema_3_validator: Optional[Requirement] = None
    # data type: TestCaseQuery
    oneof_schema_4_validator: Optional[TestCaseQuery] = None
    # data type: DefectQuery
    oneof_schema_5_validator: Optional[DefectQuery] = None
    # data type: PlanQuery
    oneof_schema_6_validator: Optional[PlanQuery] = None
    actual_instance: Optional[Union[DefectQuery, PlanQuery, Requirement, Result, Run, TestCaseQuery]] = None
    one_of_schemas: List[str] = Literal["DefectQuery", "PlanQuery", "Requirement", "Result", "Run", "TestCaseQuery"]

    model_config = {
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = SearchResponseAllOfResultEntities.model_construct()
        error_messages = []
        match = 0
        # validate data type: Run
        if not isinstance(v, Run):
            error_messages.append(f"Error! Input type `{type(v)}` is not `Run`")
        else:
            match += 1
        # validate data type: Result
        if not isinstance(v, Result):
            error_messages.append(f"Error! Input type `{type(v)}` is not `Result`")
        else:
            match += 1
        # validate data type: Requirement
        if not isinstance(v, Requirement):
            error_messages.append(f"Error! Input type `{type(v)}` is not `Requirement`")
        else:
            match += 1
        # validate data type: TestCaseQuery
        if not isinstance(v, TestCaseQuery):
            error_messages.append(f"Error! Input type `{type(v)}` is not `TestCaseQuery`")
        else:
            match += 1
        # validate data type: DefectQuery
        if not isinstance(v, DefectQuery):
            error_messages.append(f"Error! Input type `{type(v)}` is not `DefectQuery`")
        else:
            match += 1
        # validate data type: PlanQuery
        if not isinstance(v, PlanQuery):
            error_messages.append(f"Error! Input type `{type(v)}` is not `PlanQuery`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in SearchResponseAllOfResultEntities with oneOf schemas: DefectQuery, PlanQuery, Requirement, Result, Run, TestCaseQuery. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in SearchResponseAllOfResultEntities with oneOf schemas: DefectQuery, PlanQuery, Requirement, Result, Run, TestCaseQuery. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: dict) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # deserialize data into Run
        try:
            instance.actual_instance = Run.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into Result
        try:
            instance.actual_instance = Result.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into Requirement
        try:
            instance.actual_instance = Requirement.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into TestCaseQuery
        try:
            instance.actual_instance = TestCaseQuery.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into DefectQuery
        try:
            instance.actual_instance = DefectQuery.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into PlanQuery
        try:
            instance.actual_instance = PlanQuery.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into SearchResponseAllOfResultEntities with oneOf schemas: DefectQuery, PlanQuery, Requirement, Result, Run, TestCaseQuery. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into SearchResponseAllOfResultEntities with oneOf schemas: DefectQuery, PlanQuery, Requirement, Result, Run, TestCaseQuery. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        to_json = getattr(self.actual_instance, "to_json", None)
        if callable(to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Dict:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        to_dict = getattr(self.actual_instance, "to_dict", None)
        if callable(to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.milestones_api import MilestonesApi


class TestMilestonesApi(unittest.TestCase):
    """MilestonesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = MilestonesApi()

    def tearDown(self) -> None:
        pass

    def test_create_milestone(self) -> None:
        """Test case for create_milestone

        Create a new milestone.
        """
        pass

    def test_delete_milestone(self) -> None:
        """Test case for delete_milestone

        Delete milestone.
        """
        pass

    def test_get_milestone(self) -> None:
        """Test case for get_milestone

        Get a specific milestone.
        """
        pass

    def test_get_milestones(self) -> None:
        """Test case for get_milestones

        Get all milestones.
        """
        pass

    def test_update_milestone(self) -> None:
        """Test case for update_milestone

        Update milestone.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from qaseio.models.custom_field_create import CustomFieldCreate

class TestCustomFieldCreate(unittest.TestCase):
    """CustomFieldCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CustomFieldCreate:
        """Test CustomFieldCreate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CustomFieldCreate`
        """
        model = CustomFieldCreate()
        if include_optional:
            return CustomFieldCreate(
                title = '',
                value = [
                    qaseio.models.custom_field_create_value_inner.CustomFieldCreate_value_inner(
                        id = 56, 
                        title = '', )
                    ],
                entity = 0,
                type = 0,
                placeholder = '',
                default_value = '',
                is_filterable = True,
                is_visible = True,
                is_required = True,
                is_enabled_for_all_projects = True,
                projects_codes = [
                    ''
                    ]
            )
        else:
            return CustomFieldCreate(
                title = '',
                entity = 0,
                type = 0,
        )
        """

    def testCustomFieldCreate(self):
        """Test CustomFieldCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Qase.io TestOps API

    Qase TestOps API Specification.

    The version of the OpenAPI document: 1.0.0
    Contact: support@qase.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from qaseio.api.plans_api import PlansApi


class TestPlansApi(unittest.TestCase):
    """PlansApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlansApi()

    def tearDown(self) -> None:
        pass

    def test_create_plan(self) -> None:
        """Test case for create_plan

        Create a new plan.
        """
        pass

    def test_delete_plan(self) -> None:
        """Test case for delete_plan

        Delete plan.
        """
        pass

    def test_get_plan(self) -> None:
        """Test case for get_plan

        Get a specific plan.
        """
        pass

    def test_get_plans(self) -> None:
        """Test case for get_plans

        Get all plans.
        """
        pass

    def test_update_plan(self) -> None:
        """Test case for update_plan

        Update plan.
        """
        pass


if __name__ == '__main__':
    unittest.main()
